import 'package:design/design.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';

class WidgetsPage extends StatefulWidget {
  const WidgetsPage({super.key});

  @override
  State<WidgetsPage> createState() => _WidgetsPageState();
}

class _WidgetsPageState extends State<WidgetsPage> {
  final controller = TextEditingController();

  @override
  void initState() {
    super.initState();

    controller.text = 'Input text';
  }

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.end,
        children: [
          const Text('Inactive'),
          const SizedBox(height: 8),
          const LabTextField(
            decoration: InputDecoration(
              prefixIcon: Icon(Icons.lock_outline),
              suffixIcon: Icon(Icons.visibility_off_outlined),
              labelText: 'Label text',
              helperText: 'Supporting text',
            ),
          ),
          const SizedBox(height: 16),
          const Text('Focused empty'),
          const SizedBox(height: 8),
          const LabTextField(
            decoration: InputDecoration(
              prefixIcon: Icon(Icons.lock_outline),
              suffixIcon: Icon(Icons.visibility_off_outlined),
              labelText: 'Label text',
              helperText: 'Supporting text',
              prefixText: 'Prefix',
              suffixText: 'Suffix',
            ),
            autofocus: true,
          ),
          const SizedBox(height: 16),
          const Text('Focused populated'),
          const SizedBox(height: 8),
          LabTextField(
            autofocus: true,
            controller: controller,
            decoration: const InputDecoration(
              prefixIcon: Icon(Icons.lock_outline),
              suffixIcon: Icon(Icons.visibility_off_outlined),
              labelText: 'Label text',
              helperText: 'Supporting text',
              prefixText: '\$',
              suffixText: 'Suffix',
            ),
          ),
          const SizedBox(height: 16),
          const Text('Activated'),
          const SizedBox(height: 8),
          LabTextField(
            controller: controller,
            decoration: const InputDecoration(
              prefixIcon: Icon(Icons.lock_outline),
              suffixIcon: Icon(Icons.visibility_off_outlined),
              labelText: 'Label text',
              helperText: 'Supporting text',
            ),
          ),
          const SizedBox(height: 16),
          const Text('Error empty'),
          const SizedBox(height: 8),
          const LabTextField(
            decoration: InputDecoration(
              prefixIcon: Icon(Icons.lock_outline),
              suffixIcon: Icon(Icons.visibility_off_outlined),
              labelText: 'Label text',
              errorText: 'Supporting text',
            ),
          ),
          const SizedBox(height: 16),
          const Text('Error populated'),
          const SizedBox(height: 8),
          LabTextField(
            controller: controller,
            decoration: const InputDecoration(
              prefixIcon: Icon(Icons.lock_outline),
              suffixIcon: Icon(Icons.visibility_off_outlined),
              labelText: 'Label text',
              errorText: 'Supporting text',
              suffixText: 'Suffix',
            ),
          ),
          const SizedBox(height: 16),
          const Text('Disabled empty'),
          const SizedBox(height: 8),
          const LabTextField(
            enabled: false,
            decoration: InputDecoration(
              prefixIcon: Icon(Icons.lock_outline),
              suffixIcon: Icon(Icons.visibility_off_outlined),
              labelText: 'Label text',
              helperText: 'Supporting text',
            ),
          ),
          const SizedBox(height: 16),
          const Text('Disabled populated'),
          const SizedBox(height: 8),
          LabTextField(
            controller: controller,
            enabled: false,
            decoration: const InputDecoration(
              prefixIcon: Icon(Icons.lock_outline),
              suffixIcon: Icon(Icons.visibility_off_outlined),
              labelText: 'Label text',
              helperText: 'Supporting text',
              prefixText: 'Prefix',
              suffixText: 'Suffix',
            ),
          ),
          const SizedBox(height: 16),
          const SizedBox(height: 12),
          LabPrimaryButton(
            "Primary - enabled",
            minimumSize: const Size(double.infinity, 48),
            backgroundColor: const Color(0xFF0B0020),
            disabledBackgroundColor: const Color(0xFFCFCED8),
            textStyle: const TextStyle(
              fontSize: 16,
              color: Color(0xFFFFFFFF),
            ),
            onPressed: () {
              Fluttertoast.showToast(
                msg: 'You pressed on "Primary - enabled',
                toastLength: Toast.LENGTH_SHORT,
                gravity: ToastGravity.CENTER,
                timeInSecForIosWeb: 1,
                backgroundColor: Colors.black,
                textColor: Colors.white,
                fontSize: 16,
              );
            },
          ),
          const SizedBox(height: 12),
          LabPrimaryButton(
            "Primary - disabled",
            disabledBackgroundColor: Colors.blue.shade100,
            minimumSize: const Size(double.infinity, 48),
          ),
          const SizedBox(height: 24),
        ],
      ),
    );
  }

  @override
  void dispose() {
    controller.dispose();
    super.dispose();
  }
}
