import 'package:design/src/theme/app_color_light.dart';
import 'package:design/src/theme/typography/app_text_style.dart';
import 'package:flutter/material.dart';

const _smallTextScaleFactor = 0.80;
const _largeTextScaleFactor = 1.20;

/// Namespace for the app [ThemeData].
class AppTheme {
  /// Standard `ThemeData` for MyApp UI.
  static ThemeData get standard {
    return ThemeData(
      fontFamily: 'Graphik',
      useMaterial3: true,
      colorScheme: _lightColorScheme,
      appBarTheme: _appBarTheme,
      elevatedButtonTheme: _elevatedButtonTheme,
      outlinedButtonTheme: _outlinedButtonTheme,
      textTheme: _textTheme,
      dialogBackgroundColor: AppColorLight.neutral100,
      dialogTheme: _dialogTheme,
      tooltipTheme: _tooltipTheme,
      bottomSheetTheme: _bottomSheetTheme,
      tabBarTheme: _tabBarTheme,
      dividerTheme: _dividerTheme,
    );
  }

  static const ColorScheme _lightColorScheme = ColorScheme(
    brightness: Brightness.light,
    primary: AppColorLight.primary50,
    onPrimary: AppColorLight.primary100,
    primaryContainer: AppColorLight.primary95,
    onPrimaryContainer: AppColorLight.primary10,
    secondary: AppColorLight.secondary50,
    onSecondary: AppColorLight.secondary100,
    secondaryContainer: AppColorLight.secondary95,
    onSecondaryContainer: AppColorLight.secondary10,
    tertiary: AppColorLight.tertiary40,
    onTertiary: AppColorLight.tertiary100,
    tertiaryContainer: AppColorLight.tertiary90,
    onTertiaryContainer: AppColorLight.tertiary10,
    error: AppColorLight.error40,
    onError: AppColorLight.error100,
    errorContainer: AppColorLight.error90,
    onErrorContainer: AppColorLight.error10,
    background: AppColorLight.neutral100,
    onBackground: AppColorLight.neutral10,
    surface: AppColorLight.neutral99,
    onSurface: AppColorLight.neutral10,
    shadow: AppColorLight.neutral0,
    surfaceVariant: AppColorLight.neutralVariant90,
    onSurfaceVariant: AppColorLight.neutralVariant30,
    outline: AppColorLight.neutralVariant50,
  );

  // static const ColorScheme _darkColorScheme = ColorScheme(
  //   brightness: Brightness.dark,
  //   primary: AppColorDark.primary80,
  //   onPrimary: AppColorDark.primary20,
  //   primaryContainer: AppColorDark.primary30,
  //   onPrimaryContainer: AppColorDark.primary90,
  //   secondary: AppColorDark.secondary80,
  //   onSecondary: AppColorDark.secondary20,
  //   secondaryContainer: AppColorDark.secondary30,
  //   onSecondaryContainer: AppColorDark.secondary90,
  //   tertiary: AppColorDark.tertiary80,
  //   onTertiary: AppColorDark.tertiary20,
  //   tertiaryContainer: AppColorDark.tertiary30,
  //   onTertiaryContainer: AppColorDark.tertiary90,
  //   error: AppColorDark.error80,
  //   onError: AppColorDark.error20,
  //   errorContainer: AppColorDark.error30,
  //   onErrorContainer: AppColorDark.error90,
  //   background: AppColorDark.neutral10,
  //   onBackground: AppColorDark.neutral95,
  //   surface: AppColorDark.neutral10,
  //   onSurface: AppColorDark.neutral95,
  //   shadow: AppColorDark.neutral0,
  //   surfaceVariant: AppColorDark.neutralVariant30,
  //   onSurfaceVariant: AppColorDark.neutralVariant80,
  //   outline: AppColorDark.neutralVariant60,
  // );

  /// `ThemeData` for MyApp UI for small screens.
  static ThemeData get small {
    return standard.copyWith(textTheme: _smallTextTheme);
  }

  /// `ThemeData` for MyApp UI for large screens.
  static ThemeData get large {
    return standard.copyWith(textTheme: _largeTextTheme);
  }

  static const TextTheme _textTheme = TextTheme(
    displayLarge: AppTextStyle.displayLarge,
    displayMedium: AppTextStyle.displayMedium,
    displaySmall: AppTextStyle.displaySmall,
    headlineLarge: AppTextStyle.headlineLarge,
    headlineMedium: AppTextStyle.headlineMedium,
    headlineSmall: AppTextStyle.headlineSmall,
    titleLarge: AppTextStyle.titleLarge,
    titleMedium: AppTextStyle.titleMedium,
    titleSmall: AppTextStyle.titleSmall,
    bodyLarge: AppTextStyle.bodyLarge,
    bodyMedium: AppTextStyle.bodyMedium,
    bodySmall: AppTextStyle.bodySmall,
    labelLarge: AppTextStyle.labelLarge,
    labelMedium: AppTextStyle.labelMedium,
    labelSmall: AppTextStyle.labelSmall,
  );

  static TextTheme get _smallTextTheme {
    return TextTheme(
      displayLarge: AppTextStyle.displayLarge.copyWith(
        fontSize: _textTheme.displayLarge!.fontSize! * _smallTextScaleFactor,
      ),
      displayMedium: AppTextStyle.displayMedium.copyWith(
        fontSize: _textTheme.displayMedium!.fontSize! * _smallTextScaleFactor,
      ),
      displaySmall: AppTextStyle.displaySmall.copyWith(
        fontSize: _textTheme.displaySmall!.fontSize! * _smallTextScaleFactor,
      ),
      headlineLarge: AppTextStyle.headlineLarge.copyWith(
        fontSize: _textTheme.headlineLarge!.fontSize! * _smallTextScaleFactor,
      ),
      headlineMedium: AppTextStyle.headlineMedium.copyWith(
        fontSize: _textTheme.headlineMedium!.fontSize! * _smallTextScaleFactor,
      ),
      headlineSmall: AppTextStyle.headlineSmall.copyWith(
        fontSize: _textTheme.headlineSmall!.fontSize! * _smallTextScaleFactor,
      ),
      titleLarge: AppTextStyle.titleLarge.copyWith(
        fontSize: _textTheme.titleLarge!.fontSize! * _smallTextScaleFactor,
      ),
      titleMedium: AppTextStyle.titleMedium.copyWith(
        fontSize: _textTheme.titleMedium!.fontSize! * _smallTextScaleFactor,
      ),
      titleSmall: AppTextStyle.titleSmall.copyWith(
        fontSize: _textTheme.titleSmall!.fontSize! * _smallTextScaleFactor,
      ),
      bodyLarge: AppTextStyle.bodyLarge.copyWith(
        fontSize: _textTheme.bodyLarge!.fontSize! * _smallTextScaleFactor,
      ),
      bodyMedium: AppTextStyle.bodyMedium.copyWith(
        fontSize: _textTheme.bodyMedium!.fontSize! * _smallTextScaleFactor,
      ),
      bodySmall: AppTextStyle.bodySmall.copyWith(
        fontSize: _textTheme.bodySmall!.fontSize! * _smallTextScaleFactor,
      ),
      labelLarge: AppTextStyle.labelLarge.copyWith(
        fontSize: _textTheme.labelLarge!.fontSize! * _smallTextScaleFactor,
      ),
      labelMedium: AppTextStyle.labelMedium.copyWith(
        fontSize: _textTheme.labelMedium!.fontSize! * _smallTextScaleFactor,
      ),
      labelSmall: AppTextStyle.labelSmall.copyWith(
        fontSize: _textTheme.labelSmall!.fontSize! * _smallTextScaleFactor,
      ),
    );
  }

  static TextTheme get _largeTextTheme {
    return TextTheme(
      displayLarge: AppTextStyle.displayLarge.copyWith(
        fontSize: _textTheme.displayLarge!.fontSize! * _largeTextScaleFactor,
      ),
      displayMedium: AppTextStyle.displayMedium.copyWith(
        fontSize: _textTheme.displayMedium!.fontSize! * _largeTextScaleFactor,
      ),
      displaySmall: AppTextStyle.displaySmall.copyWith(
        fontSize: _textTheme.displaySmall!.fontSize! * _largeTextScaleFactor,
      ),
      headlineLarge: AppTextStyle.headlineLarge.copyWith(
        fontSize: _textTheme.headlineLarge!.fontSize! * _largeTextScaleFactor,
      ),
      headlineMedium: AppTextStyle.headlineMedium.copyWith(
        fontSize: _textTheme.headlineMedium!.fontSize! * _largeTextScaleFactor,
      ),
      headlineSmall: AppTextStyle.headlineSmall.copyWith(
        fontSize: _textTheme.headlineSmall!.fontSize! * _largeTextScaleFactor,
      ),
      titleLarge: AppTextStyle.titleLarge.copyWith(
        fontSize: _textTheme.titleLarge!.fontSize! * _largeTextScaleFactor,
      ),
      titleMedium: AppTextStyle.titleMedium.copyWith(
        fontSize: _textTheme.titleMedium!.fontSize! * _largeTextScaleFactor,
      ),
      titleSmall: AppTextStyle.titleSmall.copyWith(
        fontSize: _textTheme.titleSmall!.fontSize! * _largeTextScaleFactor,
      ),
      bodyLarge: AppTextStyle.bodyLarge.copyWith(
        fontSize: _textTheme.bodyLarge!.fontSize! * _largeTextScaleFactor,
      ),
      bodyMedium: AppTextStyle.bodyMedium.copyWith(
        fontSize: _textTheme.bodyMedium!.fontSize! * _largeTextScaleFactor,
      ),
      bodySmall: AppTextStyle.bodySmall.copyWith(
        fontSize: _textTheme.bodySmall!.fontSize! * _largeTextScaleFactor,
      ),
      labelLarge: AppTextStyle.labelLarge.copyWith(
        fontSize: _textTheme.labelLarge!.fontSize! * _largeTextScaleFactor,
      ),
      labelMedium: AppTextStyle.labelMedium.copyWith(
        fontSize: _textTheme.labelMedium!.fontSize! * _largeTextScaleFactor,
      ),
      labelSmall: AppTextStyle.labelSmall.copyWith(
        fontSize: _textTheme.labelSmall!.fontSize! * _largeTextScaleFactor,
      ),
    );
  }

  static AppBarTheme get _appBarTheme {
    return const AppBarTheme(
      color: AppColorLight.primary50,
      foregroundColor: AppColorLight.neutral100,
    );
  }

  static ElevatedButtonThemeData get _elevatedButtonTheme {
    return ElevatedButtonThemeData(
      style: ElevatedButton.styleFrom(
        elevation: 0,
        shape: const RoundedRectangleBorder(
          borderRadius: BorderRadius.all(Radius.circular(30)),
        ),
        backgroundColor: AppColorLight.primary50,
        fixedSize: const Size(208, 54),
      ),
    );
  }

  static OutlinedButtonThemeData get _outlinedButtonTheme {
    return OutlinedButtonThemeData(
      style: OutlinedButton.styleFrom(
        shape: const RoundedRectangleBorder(
          borderRadius: BorderRadius.all(Radius.circular(30)),
        ),
        side: const BorderSide(color: AppColorLight.neutral100, width: 2),
        foregroundColor: AppColorLight.neutral100,
        fixedSize: const Size(208, 54),
      ),
    );
  }

  static TooltipThemeData get _tooltipTheme {
    return const TooltipThemeData(
      decoration: BoxDecoration(
        borderRadius: BorderRadius.all(Radius.circular(5)),
      ),
      padding: EdgeInsets.all(10),
      textStyle: TextStyle(color: AppColorLight.neutral100),
    );
  }

  static DialogTheme get _dialogTheme {
    return DialogTheme(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(12),
      ),
    );
  }

  static BottomSheetThemeData get _bottomSheetTheme {
    return const BottomSheetThemeData(
      backgroundColor: AppColorLight.neutral100,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.vertical(top: Radius.circular(12)),
      ),
    );
  }

  static TabBarTheme get _tabBarTheme {
    return const TabBarTheme(
      labelColor: AppColorLight.primary100,
      unselectedLabelColor: AppColorLight.primary95,
      indicatorSize: TabBarIndicatorSize.tab,
    );
  }

  static DividerThemeData get _dividerTheme {
    return const DividerThemeData(
      space: 0,
      thickness: 1,
      color: AppColorLight.neutralVariant80,
    );
  }
}
